@@ -22,22 +22,13 @@
 # in upstream shade we will be able to use more of the shade module. Until then
 # if we want to be 'stable' we really need to be using it as a passthrough
 
+import traceback
+
 import shade
 
 
 class SanityChecks(object):
-    @staticmethod
-    def keystone(cloud):
-        [tenant for tenant in cloud.keystone_client.tenants.list()]
-
-    @staticmethod
-    def glance(cloud):
-        [image for image in cloud.glance_client.images.list()]
-
-    @staticmethod
-    def cinder(cloud):
-        [volume for volume in cloud.cinder_client.volumes.list()]
-
+    # TODO(pbourke): remove and replace with direct call to os_object
     @staticmethod
     def swift(cloud):
         [container for container in cloud.swift_client.list()]
@@ -61,8 +52,9 @@ def main():
         getattr(SanityChecks, module.params.pop("service"))(cloud)
 
         module.exit_json(changed=changed)
-    except Exception as e:
-        module.exit_json(failed=True, changed=True, msg=e)
+    except Exception:
+        module.exit_json(failed=True, changed=True,
+                         msg=repr(traceback.format_exc()))
 
 # import module snippets
 from ansible.module_utils.basic import *  # noqa
